@@ -221,7 +221,7 @@ class PooledDB(Pool_db.PooledDB):
             function or the connection constructor of the DB-API 2 module
 
         """
-        self._logger = logger if logger else logging.getLogger(__name__)
+        self._logger = logger
         try:
             threadsafety = creator.threadsafety
         except AttributeError:
@@ -295,7 +295,7 @@ class PooledDB(Pool_db.PooledDB):
         :param time_out:
         :return:
         """
-        self._logger.debug("start_check_idle time_out:%s,_idle_cachesize=%s" % (time_out, len(self._idle_cache)))
+        self._log("start_check_idle time_out:%s,_idle_cachesize=%s" % (time_out, len(self._idle_cache)))
         if not time_out:
             return False
 
@@ -319,10 +319,12 @@ class PooledDB(Pool_db.PooledDB):
                     break
                 finally:
                     if not flag and con:
+                        self._log(
+                            "check_idle error flag:%s,close conn,_idle_cachesize=%s" % (flag, len(self._idle_cache)))
                         self.close_conn(con, False)
             return True
         except Exception as e:
-            self._logger.error("check idle conn error:%s" % e)
+            self._log("check idle conn error:%s" % e, "error")
             return False
         finally:
             t = Timer(time_out, self.start_check_idle, [time_out])
@@ -377,6 +379,7 @@ class PooledDB(Pool_db.PooledDB):
         then the connection may be shared with other threads.
 
         """
+        star_time = time.time()
         if shareable and self._maxshared:
             self._lock.acquire()
             try:
@@ -389,8 +392,11 @@ class PooledDB(Pool_db.PooledDB):
                         con = self._idle_cache.pop(0)
                     except IndexError:  # else get a fresh connection
                         con = self.steady_connection()
+                        self._log("new connection timeout=%s" % (time.time() - star_time))
                     else:
+                        self._log("get cached conn timeout=%s" % (time.time() - star_time))
                         con._ping_check()  # check this connection
+                        self._log("check cached conn end timeout=%s" % (time.time() - star_time))
                     con = Pool_db.SharedDBConnection(con)
                     self._connections += 1
                 else:  # shared cache full or no more connections allowed
@@ -421,8 +427,11 @@ class PooledDB(Pool_db.PooledDB):
                     con = self._idle_cache.pop(0)
                 except IndexError:  # else get a fresh connection
                     con = self.steady_connection()
+                    self._log("new connection timeout=%s" % (time.time() - star_time))
                 else:
+                    self._log("get cached conn timeout=%s" % (time.time() - star_time))
                     con._ping_check()  # check connection
+                    self._log("check cached conn end timeout=%s" % (time.time() - star_time))
                 con = Pool_db.PooledDedicatedDBConnection(self, con)
                 self._connections += 1
             finally:
@@ -470,10 +479,22 @@ class PooledDB(Pool_db.PooledDB):
                 res = exec_sql(conn=conn, sql=sql, params=[])
                 return True
         except Exception as e:
-            self._logger.error("validate connection error:%s" % e)
+            self._log("validate connection error:%s" % e, "error")
 
         return False
 
+    def _log(self, message, level="debug"):
+        if not self._logger:
+            return False
+        if "debug" == level:
+            self._logger.debug(message)
+        elif "info" == level:
+            self._logger.info(message)
+        elif "error" == level:
+            self._logger.error(message)
+        elif "warning" == level:
+            self._logger.warning(message)
+
 
 def exec_sql(conn, sql, params=()):
     cus = None
@@ -501,6 +522,7 @@ def close_cursor(cus):
         pass
 
 
+
 class ResultThread(threading.Thread):
     def __init__(self, fun, *args, **kwargs):
         threading.Thread.__init__(self)
